@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -85,7 +85,7 @@ void StatusBarLabelToggledStateTest::shouldEmitSignalWhenClickOnLabel()
     widget.setStateString(QStringLiteral("toggle"), QStringLiteral("untoggle"));
     QSignalSpy spy(&widget, SIGNAL(toggleModeChanged(bool)));
     widget.show();
-    QTest::qWaitForWindowExposed(&widget);
+    QVERIFY(QTest::qWaitForWindowExposed(&widget));
     QTest::mouseClick(&widget, Qt::LeftButton);
     QCOMPARE(spy.count(), 1);
 
