@@ -26,17 +26,14 @@
 #include <QSpacerItem>
 #include <QVBoxLayout>
 
-#include <QDialog>
 #include <QHBoxLayout>
 #include <KLocalizedString>
 #include <KKeySequenceWidget>
-#include <KConfigGroup>
 
 using namespace MailCommon;
 
 CollectionShortcutPage::CollectionShortcutPage(QWidget *parent)
     : CollectionPropertiesPage(parent)
-    , mShortcutChanged(false)
 {
     setObjectName(QStringLiteral("KMail::CollectionShortcutPage"));
     setPageTitle(i18nc("@title:tab Shortcut settings for a folder.", "Shortcut"));
