@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2009-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2009-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -33,7 +33,7 @@ class CollectionTemplatesPage : public Akonadi::CollectionPropertiesPage
     Q_OBJECT
 public:
     explicit CollectionTemplatesPage(QWidget *parent = nullptr);
-    ~CollectionTemplatesPage();
+    ~CollectionTemplatesPage() override;
 
     void load(const Akonadi::Collection &col) override;
     void save(Akonadi::Collection &col) override;
