@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -36,19 +36,21 @@ using MailTransport::TransportManagementWidget;
 #include <AkonadiCore/agentmanager.h>
 #include <AkonadiWidgets/agenttypedialog.h>
 #include <AkonadiCore/agentinstancecreatejob.h>
+#include <identity/identitypage.h>
 
+#include <KComboBox>
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KComboBox>
 #include "kmail_debug.h"
 
-#include <QVBoxLayout>
+#include <QAbstractItemView>
 #include <QGridLayout>
 #include <QGroupBox>
 #include <QMenu>
-#include <KConfigGroup>
 #include <QLabel>
 #include <QProcess>
+#include <QVBoxLayout>
 
 QString AccountsPage::helpAnchor() const
 {
@@ -58,6 +60,10 @@ QString AccountsPage::helpAnchor() const
 AccountsPage::AccountsPage(QWidget *parent)
     : ConfigModuleWithTabs(parent)
 {
+    //Identity Tab:
+    KMail::IdentityPage *identityTab = new KMail::IdentityPage();
+    addTab(identityTab, i18nc("@title:tab Tab page where the user configures identities", "Identities"));
+
     //
     // "Receiving" tab:
     //
@@ -245,7 +251,7 @@ void AccountsPageReceivingTab::slotCustomizeAccountOrder()
 
 void AccountsPageReceivingTab::slotShowMailCheckMenu(const QString &ident, const QPoint &pos)
 {
-    QMenu *menu = new QMenu(this);
+    QMenu menu(this);
 
     bool IncludeInManualChecks;
     bool OfflineOnShutdown;
@@ -265,7 +271,7 @@ void AccountsPageReceivingTab::slotShowMailCheckMenu(const QString &ident, const
         IncludeInManualChecks = group.readEntry("IncludeInManualChecks", true);
 
         // Keep sync with kmkernel, don't forget to change there.
-        OfflineOnShutdown = group.readEntry("OfflineOnShutdown", ident.startsWith(QStringLiteral("akonadi_pop3_resource")) ? true : false);
+        OfflineOnShutdown = group.readEntry("OfflineOnShutdown", ident.startsWith(QLatin1String("akonadi_pop3_resource")) ? true : false);
 
         CheckOnStartup = group.readEntry("CheckOnStartup", false);
         QSharedPointer<RetrievalOptions> opts(new RetrievalOptions(IncludeInManualChecks, OfflineOnShutdown, CheckOnStartup));
@@ -279,31 +285,30 @@ void AccountsPageReceivingTab::slotShowMailCheckMenu(const QString &ident, const
     }
 
     if (!MailCommon::Util::isVirtualCollection(ident)) {
-        QAction *manualMailCheck = new QAction(i18nc("Label to a checkbox, so is either checked/unchecked", "Include in Manual Mail Check"), menu);
+        QAction *manualMailCheck = new QAction(i18nc("Label to a checkbox, so is either checked/unchecked", "Include in Manual Mail Check"), &menu);
         manualMailCheck->setCheckable(true);
         manualMailCheck->setChecked(IncludeInManualChecks);
         manualMailCheck->setData(ident);
-        menu->addAction(manualMailCheck);
+        menu.addAction(manualMailCheck);
         connect(manualMailCheck, &QAction::toggled, this, &AccountsPageReceivingTab::slotIncludeInCheckChanged);
     }
 
-    QAction *switchOffline = new QAction(i18nc("Label to a checkbox, so is either checked/unchecked", "Switch offline on KMail Shutdown"), menu);
+    QAction *switchOffline = new QAction(i18nc("Label to a checkbox, so is either checked/unchecked", "Switch offline on KMail Shutdown"), &menu);
     switchOffline->setCheckable(true);
     switchOffline->setChecked(OfflineOnShutdown);
     switchOffline->setData(ident);
-    menu->addAction(switchOffline);
+    menu.addAction(switchOffline);
     connect(switchOffline, &QAction::toggled, this, &AccountsPageReceivingTab::slotOfflineOnShutdownChanged);
 
-    QAction *checkOnStartup = new QAction(i18n("Check mail on startup"), menu);
+    QAction *checkOnStartup = new QAction(i18n("Check mail on startup"), &menu);
     checkOnStartup->setCheckable(true);
     checkOnStartup->setChecked(CheckOnStartup);
     checkOnStartup->setData(ident);
-    menu->addAction(checkOnStartup);
+    menu.addAction(checkOnStartup);
 
     connect(checkOnStartup, &QAction::toggled, this, &AccountsPageReceivingTab::slotCheckOnStatupChanged);
 
-    menu->exec(mAccountsReceiving.mAccountsReceiving->view()->mapToGlobal(pos));
-    delete menu;
+    menu.exec(mAccountsReceiving.mAccountsReceiving->view()->mapToGlobal(pos));
 }
 
 void AccountsPageReceivingTab::slotCheckOnStatupChanged(bool checked)
