@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,8 +28,6 @@
 
 KMComposerCreateNewComposerJob::KMComposerCreateNewComposerJob(QObject *parent)
     : QObject(parent)
-    , mMsg(nullptr)
-    , mCurrentIdentity(0)
 {
 }
 
@@ -59,7 +57,7 @@ void KMComposerCreateNewComposerJob::slotCreateNewComposer(bool forceCursorPosit
     deleteLater();
 }
 
-void KMComposerCreateNewComposerJob::setCurrentIdentity(const uint &currentIdentity)
+void KMComposerCreateNewComposerJob::setCurrentIdentity(uint currentIdentity)
 {
     mCurrentIdentity = currentIdentity;
 }
