@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -29,7 +29,7 @@ class CreateTaskJob : public KJob
     Q_OBJECT
 public:
     explicit CreateTaskJob(const Akonadi::Item::List &items, QObject *parent = nullptr);
-    ~CreateTaskJob();
+    ~CreateTaskJob() override;
 
     void start() override;
 private:
